@@ -6,7 +6,10 @@ use proc_macro2::{Ident, Span, TokenStream};
 use quote::TokenStreamExt;
 
 pub mod attributes {
-    use crate::ir::{comp::SpecialMemberKind, function::Visibility};
+    use crate::{
+        codegen::helpers::ast_ty,
+        ir::{comp::SpecialMemberKind, function::Visibility, layout::Layout},
+    };
     use proc_macro2::{Ident, Span, TokenStream};
     use std::str::FromStr;
 
@@ -96,8 +99,7 @@ pub mod attributes {
 
     pub fn visibility(visibility: Visibility) -> TokenStream {
         match visibility {
-            Visibility::Public => quote! {
-            },
+            Visibility::Public => quote! {},
             Visibility::Protected => quote! {
                 #[bindgen_visibility_protected]
             },
@@ -119,6 +121,19 @@ pub mod attributes {
         }
     }
 
+    pub fn layout(layout: &Layout) -> TokenStream {
+        let sz = ast_ty::int_expr(layout.size as i64);
+        let align = ast_ty::int_expr(layout.align as i64);
+        let packed = if layout.packed {
+            quote! { true }
+        } else {
+            quote! { false }
+        };
+        quote! {
+            #[bindgen_layout(#sz, #align, #packed)]
+        }
+    }
+
     pub fn special_member(kind: SpecialMemberKind) -> TokenStream {
         let kind_str = match kind {
             SpecialMemberKind::DefaultConstructor => "default_ctor",
